From 3bfcdbbf124ada52e8245aaeb3fa8cb539aa2b9b Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Sun, 6 Nov 2011 02:31:21 -0600
Subject: Additional kde to tde renaming

---
 arts/builder/Makefile.am                          |  2 +-
 arts/gui/kde/Makefile.am                          | 10 +++++-----
 configure.in.bot                                  |  4 ++--
 doc/artsbuilder/faq.docbook                       |  2 +-
 juk/Makefile.am                                   |  4 ++--
 juk/systemtray.cpp                                |  2 +-
 kaboodle/Makefile.am                              |  8 ++++----
 kaudiocreator/Makefile.am                         |  4 ++--
 kfile-plugins/au/Makefile.am                      |  2 +-
 kfile-plugins/avi/Makefile.am                     |  2 +-
 kfile-plugins/flac/Makefile.am                    |  2 +-
 kfile-plugins/m3u/Makefile.am                     |  2 +-
 kfile-plugins/mp3/Makefile.am                     |  2 +-
 kfile-plugins/mpc/Makefile.am                     |  2 +-
 kfile-plugins/mpeg/Makefile.am                    |  2 +-
 kfile-plugins/ogg/Makefile.am                     |  2 +-
 kfile-plugins/sid/Makefile.am                     |  2 +-
 kfile-plugins/theora/Makefile.am                  |  2 +-
 kfile-plugins/wav/Makefile.am                     |  2 +-
 kioslave/audiocd/plugins/lame/collectingprocess.h |  2 +-
 kmid/Makefile.am                                  |  2 +-
 kmid/history.txt                                  |  2 +-
 kmid/ktrianglebutton.cpp                          |  2 +-
 kmid/ktrianglebutton.h                            |  2 +-
 kmix/Makefile.am                                  |  2 +-
 krec/Makefile.am                                  | 12 ++++++------
 krec/krecord.cpp                                  |  4 ++--
 kscd/Makefile.am                                  |  2 +-
 kscd/kscdmagic/Makefile.am                        |  2 +-
 mpeglib/example/yaf/yafcore/Makefile.am           |  2 +-
 noatun/Makefile.am                                |  2 +-
 noatun/app/Makefile.am                            |  2 +-
 noatun/library/engine.cpp                         |  4 ++--
 33 files changed, 50 insertions(+), 50 deletions(-)

diff --git a/arts/builder/Makefile.am b/arts/builder/Makefile.am
index a6e9b4d7..ec43c407 100644
--- a/arts/builder/Makefile.am
+++ b/arts/builder/Makefile.am
@@ -21,7 +21,7 @@ noinst_HEADERS = qttableview.h
 
 METASOURCES = AUTO
 
-artsbuilder_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl
+artsbuilder_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl
 
 # the libraries to link against. Be aware of the order. First the libraries,
 # that depend on the following ones.
diff --git a/arts/gui/kde/Makefile.am b/arts/gui/kde/Makefile.am
index 8dd89ff1..4dd4c650 100644
--- a/arts/gui/kde/Makefile.am
+++ b/arts/gui/kde/Makefile.am
@@ -15,20 +15,20 @@ libartsgui_kde_la_SOURCES = kwidget_impl.cpp kbutton_impl.cpp \
   klevelmeter_normalbars.cpp klevelmeter_firebars.cpp \
   ktickmarks_impl.cpp kvolumefader_impl.cpp klabel_impl.cpp
 
-libartsgui_kde_la_LIBADD = $(LIB_KIO) -lkdecore -lkdeui \
+libartsgui_kde_la_LIBADD = $(LIB_KIO) -ltdecore -ltdeui \
   $(top_builddir)/arts/gui/common/libartsgui_idl.la
 libartsgui_kde_la_LDFLAGS = $(all_libraries) -no-undefined
 libartsgui_kde_la_COMPILE_FIRST = ../common/artsgui.h
 
 artstestgui_SOURCES = artstestgui.cpp
-artstestgui_LDADD = -lqtmcop -lkdecore -lartsflow \
+artstestgui_LDADD = -lqtmcop -ltdecore -lartsflow \
   $(top_builddir)/arts/gui/common/libartsgui_idl.la
-artstestgui_LDFLAGS	= $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+artstestgui_LDFLAGS	= $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 dbtest_SOURCES = dbtest.cpp
-dbtest_LDADD = -lqtmcop -lkdecore -lartsflow \
+dbtest_LDADD = -lqtmcop -ltdecore -lartsflow \
 	$(top_builddir)/arts/gui/kde/libartsgui_kde.la
-dbtest_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+dbtest_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 libartsgui_kde_la_METASOURCES = AUTO
 
diff --git a/configure.in.bot b/configure.in.bot
index 9a79138a..a2b145dd 100644
--- a/configure.in.bot
+++ b/configure.in.bot
@@ -13,7 +13,7 @@ if test "x$with_taglib" = xcheck && test "x$have_taglib" = xno; then
   echo ""
   echo "You're missing TagLib.  Without TagLib KDE will not support ID3"
   echo "tags in mp3 files.  You can find taglib either in KDE's Subversion"
-  echo "repository under trunk/kdesupport/taglib or at"
+  echo "repository under trunk/tdesupport/taglib or at"
   echo "http://ktown.kde.org/~wheeler/taglib"
   all_tests=bad
 fi
@@ -31,6 +31,6 @@ if test "x$with_akode" = xcheck && test "x$have_akode" = xno; then
   echo "aKode was not found. Without it the aKode aRts-plugin will not be"
   echo "installed, and aRts will be unable to play many music formats."
   echo "You can find aKode in KDE's Subversion repository under"
-  echo "trunk/kdesupport/akode."
+  echo "trunk/tdesupport/akode."
   all_tests=bad
 fi
diff --git a/doc/artsbuilder/faq.docbook b/doc/artsbuilder/faq.docbook
index c5b111ec..bfaaf18c 100644
--- a/doc/artsbuilder/faq.docbook
+++ b/doc/artsbuilder/faq.docbook
@@ -113,7 +113,7 @@ I can't play <literal role="extension">wav</literal> files with &artsd;!
 Check that &artsd; is linked to <filename>libaudiofile</filename>
 (<userinput><command>ldd</command>
 <parameter>artsd</parameter></userinput>). If it isn't, download
-kdesupport, recompile everything, and it will work.
+tdesupport, recompile everything, and it will work.
 </para>
 </answer>
 </qandaentry>
diff --git a/juk/Makefile.am b/juk/Makefile.am
index a268ea62..ed42a909 100644
--- a/juk/Makefile.am
+++ b/juk/Makefile.am
@@ -85,12 +85,12 @@ endif
 ##################################################
 
 juk_LDADD = -lm $(LDADD_GST) $(mblibs) $(LIB_KIO) $(taglib_libs) $(akode_libs) $(LIB_KHTML) $(LIB_ARTS)
-juk_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LDFLAGS_GST) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
+juk_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LDFLAGS_GST) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
 
 KDE_CXXFLAGS = $(USE_EXCEPTIONS)
 
 tagguessertest_LDADD = $(LIB_KDECORE)
-tagguessertest_LDFLAGS = $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
+tagguessertest_LDFLAGS = $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
 
 SUBDIRS = pics
 
diff --git a/juk/systemtray.cpp b/juk/systemtray.cpp
index e326ef27..ad1eb7c8 100644
--- a/juk/systemtray.cpp
+++ b/juk/systemtray.cpp
@@ -590,7 +590,7 @@ void SystemTray::mousePressEvent(TQMouseEvent *e)
 /*
  * This function copies the entirety of src into dest, starting in
  * dest at x and y.  This function exists because I was unable to find
- * a function like it in either TQImage or kdefx
+ * a function like it in either TQImage or tdefx
  */
 
 static bool copyImage(TQImage &dest, TQImage &src, int x, int y)
diff --git a/kaboodle/Makefile.am b/kaboodle/Makefile.am
index aba9dd9e..4a3f8fd8 100644
--- a/kaboodle/Makefile.am
+++ b/kaboodle/Makefile.am
@@ -15,8 +15,8 @@ libkaboodle_noinst_la_SOURCES = conf.cpp \
 libs = $(LIB_KPARTS) -lqtmcop -lkmedia2_idl -lsoundserver_idl -lartskde -lkmediaplayer
 
 libkaboodlepart_la_SOURCES = dummy.cpp
-libkaboodlepart_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
-libkaboodlepart_la_LIBADD = libkaboodle_noinst.la $(libs) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
+libkaboodlepart_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
+libkaboodlepart_la_LIBADD = libkaboodle_noinst.la $(libs) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
 
 kaboodle_SOURCES = main.cpp \
 	kaboodleapp.cpp \
@@ -27,8 +27,8 @@ dummy.cpp:
 
 CLEANFILES = dummy.cpp
 
-kaboodle_LDADD = libkaboodle_noinst.la $(libs) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
-kaboodle_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
+kaboodle_LDADD = libkaboodle_noinst.la $(libs) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
+kaboodle_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl
 
 bin_PROGRAMS = kaboodle
 
diff --git a/kaudiocreator/Makefile.am b/kaudiocreator/Makefile.am
index 51dac4d6..d2ed10cc 100644
--- a/kaudiocreator/Makefile.am
+++ b/kaudiocreator/Makefile.am
@@ -12,7 +12,7 @@ kaudiocreator_SOURCES = main.cpp kaudiocreator.cpp encoder.cpp \
 EXTRA_DIST = encoder.h kaudiocreator.h kaudiocreator.desktop encoderconfigimp.h \
 	obqueimp.h ripper.h tracksimp.h encodefileimp.h
 
-kaudiocreator_LDFLAGS = $(all_libraries) $(KDE_RPATH) -lkutils $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kaudiocreator_LDFLAGS = $(all_libraries) $(KDE_RPATH) -lkutils $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 METASOURCES = AUTO
 
@@ -20,7 +20,7 @@ messages: rc.cpp
 	$(XGETTEXT) *.cpp *.h -o $(podir)/kaudiocreator.pot
 
 kaudiocreator_LDADD = $(LIB_KIO) $(top_builddir)/libkcddb/libkcddb.la \
-	$(top_builddir)/kscd/libkcompactdisc.la $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+	$(top_builddir)/kscd/libkcompactdisc.la $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 KDE_ICON = AUTO
 
diff --git a/kfile-plugins/au/Makefile.am b/kfile-plugins/au/Makefile.am
index d6aa31d9..adf7a58b 100644
--- a/kfile-plugins/au/Makefile.am
+++ b/kfile-plugins/au/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_au.h
 kde_module_LTLIBRARIES = kfile_au.la
 
 kfile_au_la_SOURCES = kfile_au.cpp 
-kfile_au_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
+kfile_au_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
 kfile_au_la_LIBADD = $(LIB_KIO)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/avi/Makefile.am b/kfile-plugins/avi/Makefile.am
index 664e81ad..760bf941 100644
--- a/kfile-plugins/avi/Makefile.am
+++ b/kfile-plugins/avi/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_avi.h
 kde_module_LTLIBRARIES = kfile_avi.la
 
 kfile_avi_la_SOURCES = kfile_avi.cpp 
-kfile_avi_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
+kfile_avi_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
 kfile_avi_la_LIBADD = $(LIB_KIO)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/flac/Makefile.am b/kfile-plugins/flac/Makefile.am
index 2e218b1a..17e080ee 100644
--- a/kfile-plugins/flac/Makefile.am
+++ b/kfile-plugins/flac/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_flac.h
 kde_module_LTLIBRARIES = kfile_flac.la
 
 kfile_flac_la_SOURCES = kfile_flac.cpp
-kfile_flac_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor $(taglib_libs) -module $(KDE_PLUGIN)
+kfile_flac_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor $(taglib_libs) -module $(KDE_PLUGIN)
 kfile_flac_la_LIBADD = $(LIB_KIO)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/m3u/Makefile.am b/kfile-plugins/m3u/Makefile.am
index acc4e2c3..2d1575ce 100644
--- a/kfile-plugins/m3u/Makefile.am
+++ b/kfile-plugins/m3u/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_m3u.h
 kde_module_LTLIBRARIES = kfile_m3u.la
 
 kfile_m3u_la_SOURCES = kfile_m3u.cpp
-kfile_m3u_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
+kfile_m3u_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
 kfile_m3u_la_LIBADD = $(LIB_KSYCOCA)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/mp3/Makefile.am b/kfile-plugins/mp3/Makefile.am
index 95ce744c..9d573b6e 100644
--- a/kfile-plugins/mp3/Makefile.am
+++ b/kfile-plugins/mp3/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_mp3.h
 kde_module_LTLIBRARIES = kfile_mp3.la
 
 kfile_mp3_la_SOURCES = kfile_mp3.cpp
-kfile_mp3_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor $(taglib_libs) -module $(KDE_PLUGIN)
+kfile_mp3_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor $(taglib_libs) -module $(KDE_PLUGIN)
 kfile_mp3_la_LIBADD = $(LIB_KIO)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/mpc/Makefile.am b/kfile-plugins/mpc/Makefile.am
index a72cf3d0..b8470797 100644
--- a/kfile-plugins/mpc/Makefile.am
+++ b/kfile-plugins/mpc/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_mpc.h
 kde_module_LTLIBRARIES = kfile_mpc.la
 
 kfile_mpc_la_SOURCES = kfile_mpc.cpp
-kfile_mpc_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor $(taglib_libs) -module $(KDE_PLUGIN)
+kfile_mpc_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor $(taglib_libs) -module $(KDE_PLUGIN)
 kfile_mpc_la_LIBADD = $(LIB_KIO)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/mpeg/Makefile.am b/kfile-plugins/mpeg/Makefile.am
index 41d79e11..a7733f93 100644
--- a/kfile-plugins/mpeg/Makefile.am
+++ b/kfile-plugins/mpeg/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_mpeg.h
 kde_module_LTLIBRARIES = kfile_mpeg.la
 
 kfile_mpeg_la_SOURCES = kfile_mpeg.cpp
-kfile_mpeg_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
+kfile_mpeg_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
 kfile_mpeg_la_LIBADD = $(LIB_KIO)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/ogg/Makefile.am b/kfile-plugins/ogg/Makefile.am
index ee4f19b7..4002a77e 100644
--- a/kfile-plugins/ogg/Makefile.am
+++ b/kfile-plugins/ogg/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_ogg.h
 kde_module_LTLIBRARIES = kfile_ogg.la
 
 kfile_ogg_la_SOURCES = kfile_ogg.cpp vcedit.c
-kfile_ogg_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
+kfile_ogg_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
 kfile_ogg_la_LIBADD = $(LIB_KIO) -logg -lvorbis -lvorbisfile
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/sid/Makefile.am b/kfile-plugins/sid/Makefile.am
index fbb77d51..43e1b523 100644
--- a/kfile-plugins/sid/Makefile.am
+++ b/kfile-plugins/sid/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_sid.h
 kde_module_LTLIBRARIES = kfile_sid.la
 
 kfile_sid_la_SOURCES = kfile_sid.cpp
-kfile_sid_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
+kfile_sid_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
 kfile_sid_la_LIBADD = $(LIB_KIO)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/theora/Makefile.am b/kfile-plugins/theora/Makefile.am
index 78bb27c9..7f31443a 100644
--- a/kfile-plugins/theora/Makefile.am
+++ b/kfile-plugins/theora/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_theora.h
 kde_module_LTLIBRARIES = kfile_theora.la
 
 kfile_theora_la_SOURCES = kfile_theora.cpp
-kfile_theora_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
+kfile_theora_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
 kfile_theora_la_LIBADD = $(LIB_KIO) -logg -lvorbis -ltheora
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kfile-plugins/wav/Makefile.am b/kfile-plugins/wav/Makefile.am
index 551c088b..45e1eef6 100644
--- a/kfile-plugins/wav/Makefile.am
+++ b/kfile-plugins/wav/Makefile.am
@@ -9,7 +9,7 @@ noinst_HEADERS   = kfile_wav.h
 kde_module_LTLIBRARIES = kfile_wav.la
 
 kfile_wav_la_SOURCES = kfile_wav.cpp 
-kfile_wav_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
+kfile_wav_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -module $(KDE_PLUGIN)
 kfile_wav_la_LIBADD = $(LIB_KIO)
 
 # let automoc handle all of the meta source files (moc)
diff --git a/kioslave/audiocd/plugins/lame/collectingprocess.h b/kioslave/audiocd/plugins/lame/collectingprocess.h
index 6b3b2f37..d5f2df94 100644
--- a/kioslave/audiocd/plugins/lame/collectingprocess.h
+++ b/kioslave/audiocd/plugins/lame/collectingprocess.h
@@ -1,7 +1,7 @@
 /*  -*- mode: C++ -*-
     collectingprocess.h
 
-    This file is a copy of the collectingprocess.h which is part of kdepim/libtdepim.
+    This file is a copy of the collectingprocess.h which is part of tdepim/libtdepim.
     Copyright (c) 2004 Ingo Kloecker <kloecker@kde.org>
 
     This library is free software; you can redistribute it and/or
diff --git a/kmid/Makefile.am b/kmid/Makefile.am
index dbcb99e5..d4c9545c 100644
--- a/kmid/Makefile.am
+++ b/kmid/Makefile.am
@@ -28,7 +28,7 @@ noinst_HEADERS = kmidframe.h kmidclient.h kdisptext.h \
         channelcfgdlg.h instrname.h rhythmview.h \
         songlist.h slman.h kmid_part.h
 
-kmid_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kmid_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kmid_SOURCES = main.cpp
 kmid_LDADD   = libkmidlib.la
 
diff --git a/kmid/history.txt b/kmid/history.txt
index c436db0b..77ad9f5f 100644
--- a/kmid/history.txt
+++ b/kmid/history.txt
@@ -550,7 +550,7 @@ Sunday 5-3-2000
   QScrollView)
 
 Sunday 2-4-2000
-- Now Libkmid links with kdecore and qt in order to use a KConfig object to
+- Now Libkmid links with tdecore and qt in order to use a KConfig object to
 read the default settings as saved by the user with the midi kcontrol module.
 - It creates a "dummy" KInstance in case of the application being a non-KDE
 application.
diff --git a/kmid/ktrianglebutton.cpp b/kmid/ktrianglebutton.cpp
index f2c47ca5..348a2944 100644
--- a/kmid/ktrianglebutton.cpp
+++ b/kmid/ktrianglebutton.cpp
@@ -20,7 +20,7 @@
     Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
-    Note: This widget was based on KButton as found in the kdelibs/kdeui
+    Note: This widget was based on KButton as found in the kdelibs/tdeui
     KButton was originally copyrighted by Torben Weis (weis@kde.org)
     and Matthias Ettrich (ettrich@kde.org) on 1997
 
diff --git a/kmid/ktrianglebutton.h b/kmid/ktrianglebutton.h
index c67a0dad..6764c95d 100644
--- a/kmid/ktrianglebutton.h
+++ b/kmid/ktrianglebutton.h
@@ -20,7 +20,7 @@
     Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
-    Note: This widget was copied from KButton as found in the kdelibs/kdeui
+    Note: This widget was copied from KButton as found in the kdelibs/tdeui
     KButton was originally copyrighted by Torben Weis (weis@kde.org)
     and Matthias Ettrich (ettrich@kde.org) on 1997
      
diff --git a/kmix/Makefile.am b/kmix/Makefile.am
index 307c8168..42f09d33 100644
--- a/kmix/Makefile.am
+++ b/kmix/Makefile.am
@@ -3,7 +3,7 @@ INCLUDES= $(all_includes)
 
 bin_PROGRAMS = 
 lib_LTLIBRARIES = 
-kdeinit_LTLIBRARIES = kmix.la kmixctrl.la
+tdeinit_LTLIBRARIES = kmix.la kmixctrl.la
 kde_module_LTLIBRARIES = kmix_panelapplet.la
 
 
diff --git a/krec/Makefile.am b/krec/Makefile.am
index cbce157d..c14df4ac 100644
--- a/krec/Makefile.am
+++ b/krec/Makefile.am
@@ -27,7 +27,7 @@ METASOURCES = AUTO
 
 bin_PROGRAMS =
 lib_LTLIBRARIES =
-kdeinit_LTLIBRARIES = krec.la
+tdeinit_LTLIBRARIES = krec.la
 
 kde_module_LTLIBRARIES = kcm_krec.la kcm_krec_files.la libkrecexport_wave.la
 
@@ -42,7 +42,7 @@ krec_la_SOURCES = \
 		main.cpp \
 		krecord.cpp
 
-krec_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
+krec_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
 krec_la_LIBADD = \
 	lib_krec_common.la \
 	$(top_builddir)/arts/gui/kde/libartsgui_kde.la \
@@ -50,12 +50,12 @@ krec_la_LIBADD = \
 	-lartskde $(LIBDL) $(LIB_KIO) $(LIB_KDEUI) $(LIB_KUTILS)
 
 kcm_krec_la_SOURCES = krecconfigure.cpp
-kcm_krec_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
+kcm_krec_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
 
 kcm_krec_la_LIBADD = lib_krec_common.la $(LIB_KUTILS)
 
 kcm_krec_files_la_SOURCES = krecconfig_files.cpp
-kcm_krec_files_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
+kcm_krec_files_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
 
 kcm_krec_files_la_LIBADD = lib_krec_common.la $(LIB_KUTILS)
 
@@ -64,12 +64,12 @@ lib_krec_common_la_SOURCES = \
 	krecexport_template.cpp \
 	krecconfig_fileswidget.cpp
 
-lib_krec_common_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
+lib_krec_common_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
 
 lib_krec_common_la_LIBADD = $(LIB_KDEUI) $(LIB_KIO)
 
 libkrecexport_wave_la_SOURCES = krecexport_wave.cpp
-libkrecexport_wave_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
+libkrecexport_wave_la_LDFLAGS = $(all_libraries) -module $(KDE_PLUGIN) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor -lmcop -lartsflow_idl -lkmedia2_idl -lsoundserver_idl -L../arts/modules/effects -lartsmoduleseffects
 
 libkrecexport_wave_la_LIBADD = lib_krec_common.la
 
diff --git a/krec/krecord.cpp b/krec/krecord.cpp
index 37b0d1cd..1a93ce13 100644
--- a/krec/krecord.cpp
+++ b/krec/krecord.cpp
@@ -252,10 +252,10 @@ void KRecPrivate::forceTipOfDay() {
 }
 
 void KRecPrivate::execaRtsControl() {
-	kapp->kdeinitExec( "artscontrol" );
+	kapp->tdeinitExec( "artscontrol" );
 }
 void KRecPrivate::execKMix() {
-	kapp->kdeinitExec( "kmix" );
+	kapp->tdeinitExec( "kmix" );
 }
 
 /**
diff --git a/kscd/Makefile.am b/kscd/Makefile.am
index 7d999f50..edb2eaf6 100644
--- a/kscd/Makefile.am
+++ b/kscd/Makefile.am
@@ -23,7 +23,7 @@ libkcompactdisc_la_LDFLAGS = $(all_libraries) -lpthread
 
 kde_kcfg_DATA = kscd.kcfg
 
-kscd_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kscd_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 kscd_LDADD = $(LIBCDROM) $(LIBCDAUDIO) \
 	     $(LIBFPE) $(LIB_KIO) -lkutils $(top_builddir)/libkcddb/libkcddb.la \
 	     libkcompactdisc.la -lpthread
diff --git a/kscd/kscdmagic/Makefile.am b/kscd/kscdmagic/Makefile.am
index 073bad0c..e28ba7c4 100644
--- a/kscd/kscdmagic/Makefile.am
+++ b/kscd/kscdmagic/Makefile.am
@@ -26,7 +26,7 @@ bin_PROGRAMS = 	kscdmagic
 kscdmagic_SOURCES = core.cpp main.cpp sound.cpp xlibwrap.cpp xlib.c
 
 # the library search path. 
-kscdmagic_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kscdmagic_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 
 # the libraries to link against. Be aware of the order. First the libraries,
 # that depend on the following ones.
diff --git a/mpeglib/example/yaf/yafcore/Makefile.am b/mpeglib/example/yaf/yafcore/Makefile.am
index 95119cb5..86429887 100644
--- a/mpeglib/example/yaf/yafcore/Makefile.am
+++ b/mpeglib/example/yaf/yafcore/Makefile.am
@@ -32,7 +32,7 @@ libyafcore_la_SOURCES	=	buffer.cpp \
 libyafcore_la_LDFLAGS	=	$(all_libraries) $(KDE_RPATH) \
 				-no-undefined -avoid-version
 
-libyafcore_la_LIBADD	=	-lkdefakes $(THIS_LIB_LIBS)
+libyafcore_la_LIBADD	=	-ltdefakes $(THIS_LIB_LIBS)
 
 
 
diff --git a/noatun/Makefile.am b/noatun/Makefile.am
index 240c3225..3ab6112b 100644
--- a/noatun/Makefile.am
+++ b/noatun/Makefile.am
@@ -16,7 +16,7 @@ kconfdir = $(libdir)/kconf_update_bin
 kconf_PROGRAMS = noatun20update
 
 noatun20update_SOURCES  = noatun20update.cpp
-noatun20update_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+noatun20update_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
 noatun20update_LDADD = $(LIB_QT)
 
 messages:
diff --git a/noatun/app/Makefile.am b/noatun/app/Makefile.am
index 59d8dbd2..3750e4b8 100644
--- a/noatun/app/Makefile.am
+++ b/noatun/app/Makefile.am
@@ -1,6 +1,6 @@
 INCLUDES = -I$(top_srcdir)/noatun/library -I$(kde_includes)/arts $(all_includes)
 
-kdeinit_LTLIBRARIES = noatun.la
+tdeinit_LTLIBRARIES = noatun.la
 noatun_la_SOURCES = main.cpp
 noatun_la_LDFLAGS = $(KDE_RPATH) $(all_libraries) -module -avoid-version
 noatun_la_LIBADD = -lqtmcop -lkmedia2_idl -lsoundserver_idl $(top_builddir)/noatun/library/libnoatun.la
diff --git a/noatun/library/engine.cpp b/noatun/library/engine.cpp
index 36863a0c..9cd34e7d 100644
--- a/noatun/library/engine.cpp
+++ b/noatun/library/engine.cpp
@@ -482,7 +482,7 @@ bool Engine::initArts()
 				X11CommConfig.sync();
 			}
 
-			cmdline = TQFile::encodeName(KStandardDirs::findExe(TQString::tqfromLatin1("kdeinit_wrapper")));
+			cmdline = TQFile::encodeName(KStandardDirs::findExe(TQString::tqfromLatin1("tdeinit_wrapper")));
 			cmdline += " ";
 
 			if (rt)
@@ -502,7 +502,7 @@ bool Engine::initArts()
 				// We could have a race-condition here.
 				// The correct way to do it is to make artsd fork-and-exit
 				// after starting to listen to connections (and running artsd
 				// directly instead of using kdeinit), but this is better
 				// than nothing.
 				int time = 0;
 				do
@@ -502,7 +502,7 @@ bool Engine::initArts()
 				// The correct way to do it is to make artsd fork-and-exit
 				// after starting to listen to connections (and running artsd
-				// directly instead of using kdeinit), but this is better
+				// directly instead of using tdeinit), but this is better
 				// than nothing.
 				int time = 0;
-- 
cgit v1.2.3

